<?php
/**
 * Description: Creates database tables used by DiveBook
 * Author: Per Ola Saether
 */

//Database table versions
global $gh_db_table_stadium_version;
global $gh_db_table_competition_version;
global $gh_db_table_team_version;
global $gh_db_table_visits_version;

$gh_db_table_stadium_version        = "1.0";
$gh_db_table_team_version           = "1.0";
$gh_db_table_visits_version         = "2.0";
$gh_db_table_competition_version    = "1.0";

//Create database tables needed by the Groundhopping widget
function gh_db_create () {
    gh_create_table_stadium();
    gh_create_table_team();
    gh_create_table_visits();
    gh_create_table_competition();
}

//Create stadium table
function gh_create_table_stadium() {
    //Get the table name with the WP database prefix
    global $wpdb;
    $table_name = $wpdb->prefix . "gh_stadium";
    global $gh_db_table_stadium_version;
         $installed_ver = get_option( "gh_db_table_stadium_version" );
          //Check if the table already exists and if the table is up to date, if not create it
         if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name
                 ||  $installed_ver != $gh_db_table_stadium_version ) {
             $sql = "CREATE TABLE " . $table_name . " (
                   id mediumint(9) NOT NULL AUTO_INCREMENT,
                   name text NOT NULL,
                   latitude float(9,6) NOT NULL,
                   longitude float(9,6) NOT NULL,
                   UNIQUE KEY id (id)
                 );";
		 
        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);
        update_option( "gh_db_table_stadium_version", $gh_db_table_stadium_version );
    }

    add_option("gh_db_table_stadium_version", $gh_db_table_stadium_version);
}

//Create team table
function gh_create_table_team() {
    //Get the table name with the WP database prefix
    global $wpdb;
    $table_name = $wpdb->prefix . "gh_team";
    global $gh_db_table_team_version;
         $installed_ver = get_option( "gh_db_table_team_version" );
          //Check if the table already exists and if the table is up to date, if not create it
         if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name
                 ||  $installed_ver != $gh_db_table_team_version ) {
             $sql = "CREATE TABLE " . $table_name . " (
                   id mediumint(9) NOT NULL AUTO_INCREMENT,
                   name text NOT NULL,
                   UNIQUE KEY id (id)
                 );";

        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);
        update_option( "gh_db_table_team_version", $gh_db_table_team_version );
    }

    add_option("gh_db_table_team_version", $gh_db_table_team_version);
}

//Create visits table
function gh_create_table_visits() {
    //Get the table name with the WP database prefix
    global $wpdb;
    $table_name = $wpdb->prefix . "gh_visits";
    global $gh_db_table_visits_version;
         $installed_ver = get_option( "gh_db_table_visits_version" );
          //Check if the table already exists and if the table is up to date, if not create it
         if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name
                 ||  $installed_ver != $gh_db_table_visits_version ) {
             $sql = "CREATE TABLE " . $table_name . " (
           id mediumint(9) NOT NULL AUTO_INCREMENT,
           user bigint(20) NOT NULL,
           match_time datetime NOT NULL,
		   team_home mediumint(9) NOT NULL,
		   team_guest mediumint(9) NOT NULL,
		   stadium_id mediumint(9) NOT NULL,
		   competition_id mediumint(9),
                   UNIQUE KEY id (id)
                 );";

        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);
        update_option( "gh_db_table_visits_version", $gh_db_table_visits_version );
    }

    add_option("gh_db_table_visits_version", $gh_db_table_visits_version);
}

//Create visits table
function gh_create_table_competition() {
    //Get the table name with the WP database prefix
    global $wpdb;
    $table_name = $wpdb->prefix . "gh_competition";
    global $gh_db_table_competition_version;
         $installed_ver = get_option( "gh_db_table_competition_version" );
          //Check if the table already exists and if the table is up to date, if not create it
         if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name
                 ||  $installed_ver != $gh_db_table_competition_version ) {
             $sql = "CREATE TABLE " . $table_name . " (
                   id mediumint(9) NOT NULL AUTO_INCREMENT,
                   name text NOT NULL,
                   UNIQUE KEY id (id)
                 );";

        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);
        update_option( "gh_db_table_competition_version", $gh_db_table_competition_version );
    }

    add_option("gh_db_table_competition_version", $gh_db_table_competition_version);
}

?>