<?php
/*
Plugin Name: de.andismirre.groundhopping
Plugin URI: http://www.andismirre.de/blog/?page_id=332
Description: Plugin with groundhopping log functionality
Version: 0.9.202404090010
Author: Andreas Smirnow
Author URI: http://www.andismirre.de
License: GPL2
*/

require 'plugin-updates/plugin-update-checker.php';
$updateChecker = PucFactory::buildUpdateChecker('http://www.andismirre.de/share/groundhopping.json', __FILE__);

// Here's how you can add query arguments to the URL.
// function addSecretKey($query){$query['secret'] = 'foo'; return $query; }
// $updateChecker->addQueryArgFilter('addSecretKey');

include("settings.php");
include("widget.php");
include("functions.php");

//Include the database file
include("functions/database.php");

//Activation hook so the DB is created when plugin is activated
register_activation_hook(__FILE__, 'gh_db_create');

//Add filter to filter executable php code in content
add_shortcode("groundhopping", "gh_process_shortcode");

//Add action to load css
add_action('wp_print_styles', 'groundhopping_load_css');

//Add script
add_action('wp_print_scripts', 'groundhopping_enqueue_js');

// Add actions
add_action('init', 'gh_action_init');

function gh_action_init() {
  // Localization
  load_plugin_textdomain('groundhopping', false, basename( dirname( __FILE__ ) ) . '/languages' );
}


/*
  available parameters among the entire plugin
*/
$available_parameters = array("scrolled", "deletestadium", "showVisit", "showMap", "stadium", "competition", 
                              "filter_team", "filter_home", "filter_guest", "filter_stadium", "filter_competition");

function gh_process_shortcode($atts, $content = "") {
  if (is_null($content)) {
    include_once("errorbox.php");
    $msg = "please check your post/page configuration. <br />";
    show_error_box("invalid parameter", $msg . "you used an invalid parameter!");
    return;
  }
  
  if (strlen($content) < 1) {
    include_once("errorbox.php");
    $msg = "please check your post/page configuration. <br />";
    show_error_box("no parameters used", $msg . "no parameters are used!");
    return;
  }
  
  include_once("stadiumpostactions.php");
  include_once("teampostactions.php");
  include_once("visitspostactions.php");
  include_once("competitionpostactions.php");

  if ($content == "show") gh_show();
	else if ($content == "stadiums") gh_stadiums();
	else if ($content == "teams") gh_teams();
	else if ($content == "competitions") gh_competitions();
	else gh_unknown($content);
}


function gh_show() {

	$urlWithRemovedParams = gh_remove_url_params(null);

	if (!(empty($_GET['showVisit']))) 
	{
		include("visits.php");
		if (is_user_logged_in()) { 
		  include("visitsinputform.php");
		  show_visit_form($urlWithRemovedParams);
		}
		show_visit($urlWithRemovedParams, $_GET['showVisit']);
	}
	else if (!(empty($_GET['showMap']))) 
	{
		include("map.php");
		show_map($urlWithRemovedParams);
	}
	else if (!(empty($_GET['stadium']))) 
	{
		include("stadiums.php");
		
		if (is_user_logged_in()) {
		  include("stadiuminputform.php");
		  show_stadium_form($urlWithRemovedParams);
		}
    
		show_stadium($urlWithRemovedParams, $_GET['stadium']);
	}
	else if (!(empty($_GET['team']))) 
	{
		include("teams.php");
		if (is_user_logged_in()) {
		  include("teaminputform.php");
		  show_team_form($urlWithRemovedParams);
		}
		show_team($urlWithRemovedParams, $_GET['team']);
	}
	else if (!(empty($_GET['competition']))) 
	{
		include("competition.php");
		if (is_user_logged_in()) { 
		  include("competitioninputform.php");
		  show_competition_form($urlWithRemovedParams);
		}
		show_competition($urlWithRemovedParams, $_GET['competition']);
	}
	else 
	{
		
		include_once("visits.php");
		
		if (is_user_logged_in()) {
		  show_visitslist($urlWithRemovedParams);
		
		  include_once("visitsinputform.php");
		  show_visit_form($urlWithRemovedParams);
		  show_visits_form_add_visit($urlWithRemovedParams);
		} else {
      include_once("errorbox.php");
      show_error_box("login required", "you must log in to be see your visits");
		}
	}
}

function gh_stadiums() {
	$urlWithRemovedParams = gh_remove_url_params(null);

  if (is_user_logged_in()) {
	  include("stadiuminputform.php");
	  gh_stadium_inputform($urlWithRemovedParams);
  }
  
	include("stadiums.php");
	show_stadiumlist();

	if (is_user_logged_in()) show_stadium_form_add_stadium($urlWithRemovedParams);
}

function gh_teams() {
	$urlWithRemovedParams = gh_remove_url_params(null);

  if (is_user_logged_in()) {
	  include("teaminputform.php");
	  gh_team_inputform($urlWithRemovedParams);
  }

	include("teams.php");
	show_teamlist();

	if (is_user_logged_in()) show_team_form_add_team($urlWithRemovedParams);
}

function gh_competitions() {
	$urlWithRemovedParams = gh_remove_url_params(null);

  if (is_user_logged_in()) {
	  include("competitioninputform.php");
	  gh_competition_inputform($urlWithRemovedParams);
	}

	include("competition.php");
	show_competitionlist();

	if (is_user_logged_in()) show_competition_form_add_competition($urlWithRemovedParams);
}

function gh_unknown($parameter) {
	$urlWithRemovedParams = gh_remove_url_params(null);
	include_once("errorbox.php");
  show_error_box("unknown parameter", "please check your post/page configuration. <br />you used unvalid parameter '" . $parameter . "'!");
}

function groundhopping_enqueue_js () {
	if (!is_admin()) {
		wp_deregister_script('jquery');
		wp_register_script('jquery', 'http://ajax.googleapis.com/ajax/libs/jquery/1/jquery.min.js');
		wp_enqueue_script('jquery');

		wp_deregister_script('jquery-ui');
		wp_register_script('jquery-ui', 'https://ajax.googleapis.com/ajax/libs/jqueryui/1/jquery-ui.js');
		wp_enqueue_script('jquery-ui');

    wp_enqueue_script('groundhopping-popup', plugins_url( 'script/groundhopping-popup.js', __FILE__ ), array( 'jquery', 'jquery-ui' ), '1.0.2' );
	}

}

function groundhopping_load_css() {
	wp_enqueue_style('groundhoppingDatepicker', plugins_url('css/jquery.ui.datepicker.css', __FILE__), array(), 1.0, 'screen' );
	wp_enqueue_style('divebookTheme', plugins_url('css/jquery.ui.theme.css', __FILE__), array(), 1.0, 'screen' );
  wp_enqueue_style('groundhoppingStyle', plugins_url('css/groundhopping.css', __FILE__), array(), 1.0, 'screen' );
}


function gh_remove_url_params($url)
{
  global $available_parameters;
  $params = $available_parameters;
  return gh_remove_url_params_from_array($url, $params);
}

function gh_remove_url_params_from_array($url, $params)
{
	if (!empty($url)) $In_url = $url;	
  
	$In_url = gh_getCurrentPageURL();
	trim($In_url);
	$qm = chr(63); //Creates a question mark
	$L_qm_pos = strpos($In_url, $qm) + 1; // Creates a variable that holds the position of the question mark (it may be 0 if there is no question mark)
	// When searching for the parameter, make sure that it is
	// proceeded by an & or ? and followed by an = sign
	foreach($params as $param){

		$L_search_string = ("?" . $param . "=");
		$L_param_pos = strpos($In_url,$L_search_string);
		if (!empty($L_param_pos))
		{
			// Parameter is led by ?... preserve the question mark
			$L_param_pos++;
		}
		else
		{
			$L_search_string = ("&" . $param . "=");
			$L_param_pos = strpos($In_url, $L_search_string);
		}

		if (!empty($L_param_pos))
		{
			// The parameter exists in the param string so remove it
			// Find the end of the param name value pair
			for ($i = $L_param_pos + 1; $i <= strlen($In_url); $i++)
			{
				$L_character = (substr($In_url, $i, 1));
				if ($L_character == " " or $L_character == "&")
				{
					$i ++;
					break;
				}
			}

			$In_url = gh_repair_url(substr($In_url, 0,$L_param_pos) .
			        substr($In_url, $i - 1, strlen($In_url)));
		}
	}
	return $In_url; // Return the url
}

function gh_getCurrentPageURL() {
 $pageURL = 'http';
 if ($_SERVER["HTTPS"] == "on") {$pageURL .= "s";}
 $pageURL .= "://";
 if ($_SERVER["SERVER_PORT"] != "80") {
  $pageURL .= $_SERVER["SERVER_NAME"].":".$_SERVER["SERVER_PORT"].$_SERVER["REQUEST_URI"];
 } else {
  $pageURL .= $_SERVER["SERVER_NAME"].$_SERVER["REQUEST_URI"];
 }
 return $pageURL;
}

function gh_repair_url($In_url)
{
	$L_pos = strpos($In_url, "?&");
	if (!empty($L_pos))
	{
		// Remvove the &
		$In_url = substr($In_url, 0,$L_pos + 1) .
		        substr($In_url, $L_pos + 2, strlen($In_url));
	}

	$L_pos = strpos($In_url, "&&");
	if (!empty($L_pos))
	{
		// Remove one of the &s
		$In_url = substr($In_url, 0,$L_pos + 1) .
		        substr($In_url, $L_pos + 2, strlen($In_url));
	}

	if (strpos($In_url, "?") > 0 and (strpos($In_url, "?") == strlen($L_url)))
	{
		// Then the question mark that is trailing has no parameters, remove it
		$In_url = substr($In_url, 0, strlen($L_url - 1));
	}

	return $In_url;
}


?>