<?php
/**
 * Shows the stadium map.
 */

function show_map($url) {
  
  $filteredTeam = isset($_GET['filter_team']) ? $_GET['filter_team'] : null;
  $filteredTeamHome = isset($_GET['filter_home']) ? $_GET['filter_home'] : null;
  $filteredTeamGuest = isset($_GET['filter_guest']) ? $_GET['filter_guest'] : null;
  $filteredStadium = isset($_GET['filter_stadium']) ? $_GET['filter_stadium'] : null;
  $filteredCompetition = isset($_GET['filter_competition']) ? $_GET['filter_competition'] : null;
  
  include_once("functions/stadiums.php");
  $filterClause = getStadiumListFilter($filteredTeamHome, $filteredTeamGuest, $filteredStadium, $filteredCompetition, $filteredTeam);
  $totalNumberOfStadiums = getStadiumListCount($filterClause, true);
  $stadiums = getStadiumListEntries($filterClause, true);
  
  $L_pos = strpos($url, "?");
  if($L_pos == false) $trenn = "?";
  else $trenn = "&amp;";
  
  $mapHeadline = _n('There is %d stadium known.', 'There are %d stadiums known.', $totalNumberOfStadiums, 'groundhopping');
  $listResultCountText = sprintf($mapHeadline, $totalNumberOfStadiums);
  echo sprintf("<div id=\"listAmount\">%s</div>", $listResultCountText);
  
  include_once("filter.php");
  show_filter_panel($url, $filteredTeam, $filteredTeamHome, $filteredTeamGuest, $filteredTeamStadium, $filteredCompetition);
  
  $markerImageUrl = plugins_url('images/football.png', __FILE__);
  
  $map_id = "stadiumMap_canvas";
  $mapboxAPIKey = get_option ( 'mapBoxAPI_Key' );
  
  function createImage($spaces, $variableName, $width, $height, $url) {
    $imageCode = "\n";
    $imageCode .= sprintf("%svar %s = L.icon({\n", $spaces, $variableName);
    $imageCode .= sprintf("%s    iconSize: [%d,  %d], \n", $spaces, $width, $height);
    $imageCode .= sprintf("%s    iconUrl: '%s' });\n", $spaces, $url);
    return $imageCode;
  }
  
  function createStadiumMarker($spaces, $i, $name, $lat, $lng, $iconName) {
    $markerCode = "\n";
    $markerCode .= sprintf ( "%svar markerPosition%s = L.latLng(%s, %s);\n", $spaces, $i, $lat, $lng);
    $markerCode .= sprintf ( "%svar marker%s = L.marker(markerPosition%s, { title: '%s' });\n", $spaces, $i, $i, $name);
    $markerCode .= sprintf ( "%smarker%s.setIcon(%s);\n", $spaces, $i, $iconName );
    $markerCode .= sprintf ( "%smarker%s.addTo(map);\n", $spaces, $i );
    $markerCode .= sprintf ( "%smarker%s.bindPopup('%s');\n", $spaces, $i, $name );
    $markerCode .= sprintf ( "%sbounds.extend(markerPosition%s);\n", $spaces, $i );
    return $markerCode;
  }
  
  $spaces = "        ";
  $imageName = "image";
  
  $mapContent = createImage($spaces, $imageName, 16, 16, $markerImageUrl);
  
  $i = 0;
  foreach ($stadiums as $stadium) {
    
    $name = str_replace("'", "`", $stadium->name);
    $lat = $stadium->latitude;
    $lng = $stadium->longitude;
    $mapContent .= createStadiumMarker($spaces, ++$i, $name, $lat, $lng, $imageName);
  }
  
  ?>

  <div id="stadiumMap">

    <link rel="stylesheet" href="https://unpkg.com/leaflet@1.4.0/dist/leaflet.css"
     integrity="sha512-puBpdR0798OZvTTbP4A8Ix/l+A4dHDD0DGqYW6RQ+9jxkRFclaxxQb/SJAWZfWAkuyeQUytO7+7N4QKrDh+drA=="
     crossorigin=""/>
    <script src="https://unpkg.com/leaflet@1.4.0/dist/leaflet.js"
     integrity="sha512-QVftwZFqvtRNi0ZyCtsznlKSWOStnDORoefr1enyq5mVL4tmKB3S/EnC3rRJcxCPavG10IcrVGSmPh6Qw5lwrg=="
     crossorigin=""></script>
     
    <div id="<?php echo $map_id; ?>" style="width:100%; height:300px;"></div>
    
    <script type="text/javascript"><!--
      var map;
      function initialize_stadiummap() {
        
        map = L.map('<?php echo $map_id; ?>').setView([22.5666, 88.355], 13);

        var osmLink = '<a href=\"https://www.openstreetmap.org/\">OpenStreetMap</a> contributors';
        var ccLink = '<a href=\"https://creativecommons.org/licenses/by-sa/2.0/\">CC-BY-SA</a>';
        var mapBox = 'Imagery  <a href=\"https://www.mapbox.com/\">Mapbox</a>';

        L.tileLayer('https://api.tiles.mapbox.com/v4/{id}/{z}/{x}/{y}.png?access_token={accessToken}', {
          attribution: 'Map data &copy; ' + osmLink + ', ' + ccLink + ', ' + mapBox,
          maxZoom: 18,
          id: 'mapbox.streets',
          accessToken: '<?php echo $mapboxAPIKey; ?>'
        }).addTo(map);

        var bounds = L.latLngBounds(); 
        <?php echo $mapContent; ?> 
        map.fitBounds(bounds);
      }

      document.body.onload = initialize_stadiummap;
    
//--></script>
    
  </div>
  
<?php 

  if( $filteredTeamHome != null || 
      $filteredTeamGuest != null || 
      $filteredStadium != null || 
      $filteredCompetition != null) { 
          
          ?> 
    <div class="visitClearFilter"><a href="<?php echo $url; ?>"><?php _e('clear filters', 'groundhopping');?></a></div>
<?php 

  } 
  
}

?>